document.addEventListener("DOMContentLoaded", function() {
  // Usuń stare eventy
  document.querySelectorAll('.sync-btn').forEach(btn => {
    btn.replaceWith(btn.cloneNode(true));
  });
  document.querySelectorAll('.delete-suggestion-btn').forEach(btn => {
    btn.replaceWith(btn.cloneNode(true));
  });

  // Synchronizacja sugestii
  const buttons = document.querySelectorAll('.sync-btn');
  buttons.forEach(btn => {
    btn.addEventListener('click', function(e) {
      e.preventDefault();

      const itemId = this.getAttribute('data-item-id');
      const button = this;

      button.disabled = true;

      fetch(`/admin/sync_suggestion/${itemId}`, {
        method: 'POST',
        headers: {
          'X-Requested-With': 'XMLHttpRequest'
        }
      })
      .then(response => response.json())
      .then(data => {
        showToast(data.message, data.success ? 'success' : 'danger');

        if (data.success) {
          button.innerText = '✅ Zsynchronizowano';
          button.classList.remove('btn-outline-primary');
          button.classList.add('btn-success');
        } else {
          button.disabled = false;
        }
      })
      .catch(error => {
        showToast('Błąd synchronizacji', 'danger');
        button.disabled = false;
      });
    });
  });

  // Usuwanie sugestii
  const deleteButtons = document.querySelectorAll('.delete-suggestion-btn');
  deleteButtons.forEach(btn => {
    btn.addEventListener('click', function(e) {
      e.preventDefault();

      const suggestionId = this.getAttribute('data-suggestion-id');
      const button = this;

      button.disabled = true;

      fetch(`/admin/delete_suggestion/${suggestionId}`, {
        method: 'POST',
        headers: {
          'X-Requested-With': 'XMLHttpRequest'
        }
      })
      .then(response => response.json())
      .then(data => {
        showToast(data.message, data.success ? 'success' : 'danger');

        if (data.success) {
          // Możesz usunąć cały wiersz lub np. odświeżyć kolumnę
          const row = button.closest('tr');
          if (row) {
            row.remove();
          }
        } else {
          button.disabled = false;
        }
      })
      .catch(error => {
        showToast('Błąd usuwania sugestii', 'danger');
        button.disabled = false;
      });
    });
  });
});


// Funkcja do wyświetlania toast
function showToast(message, type = 'success') {
  const toastContainer = document.getElementById('toast-container');
  const toast = document.createElement('div');
  toast.className = `toast align-items-center text-white bg-${type} border-0 show`;
  toast.role = 'alert';
  toast.style.minWidth = '250px';
  toast.innerHTML = `
    <div class="d-flex">
      <div class="toast-body">${message}</div>
      <button type="button" class="btn-close btn-close-white me-2 m-auto" data-bs-dismiss="toast" aria-label="Close"></button>
    </div>
  `;
  toastContainer.appendChild(toast);

  // Automatyczne usunięcie po 1.75 sekundy
  setTimeout(() => {
    toast.remove();
  }, 1750);
}
